==> wakuwork-0.7.2.tgz: package/README.md <==
# Wakuwork

Minimalistic React Framework

**Use it at your own risk.**

## How to try it

- https://codesandbox.io/p/sandbox/wakuwork-example-counter-mdc1yb

## How to start a new project

```bash
npm create wakuwork
```

```bash
yarn create wakuwork
```

```bash
pnpm create wakuwork
```

## Work in progress

- [x] `wakuwork dev` (development server)
- [x] `wakuwork build` (build for production)
- [x] `wakuwork start` (production server)
- [x] Exportable build
- [ ] Static site generation
- [ ] Opt-in router (reference implementation)
- [ ] Client rendering fallback

## Tweets

<details>

- https://twitter.com/dai_shi/status/1631668890861441024
- https://twitter.com/dai_shi/status/1631989295866347520
- https://twitter.com/dai_shi/status/1632005473401716736
- https://twitter.com/dai_shi/status/1632168346354593792
- https://twitter.com/dai_shi/status/1632729614450823169
- https://twitter.com/dai_shi/status/1632749501416087552
- https://twitter.com/dai_shi/status/1633262538862530561
- https://twitter.com/dai_shi/status/1633301007391424518
- https://twitter.com/dai_shi/status/1633821215206035460
- https://twitter.com/dai_shi/status/1633824588152074240
- https://twitter.com/dai_shi/status/1633826855282434048
- https://twitter.com/dai_shi/status/1634210639831867392
- https://twitter.com/dai_shi/status/1634212827706654723
- https://twitter.com/dai_shi/status/1635142924928434177
- https://twitter.com/dai_shi/status/1635149324383559681
- https://twitter.com/dai_shi/status/1635437958185766913
- https://twitter.com/dai_shi/status/1636744180902014981
- https://twitter.com/dai_shi/status/1636745339624624132
- https://twitter.com/dai_shi/status/1636746632900534273
- https://twitter.com/dai_shi/status/1637635196458778627
- https://twitter.com/dai_shi/status/1637768216817840129

</details>

## Diagrams

### Architecture

https://excalidraw.com/#json=W1apCXy3iJ3L0rIoDxtU4,AbYkm972Fm1CbIzfV5PTIQ

![wakuwork-arch](https://user-images.githubusercontent.com/490574/224886500-20833ff1-961b-4b84-972c-6471bc732de2.png)

### How React Server Functions Work

https://excalidraw.com/#json=fMeNJovUG7PGnpvP64XVw,kjZBTeM2KPZKhWtALDOY8A

![react-server-functions](https://user-images.githubusercontent.com/490574/225330279-e10cee1e-ffb9-49d1-b47c-6c46eb7f6c3a.png)

### How Wakuwork counter example communicates with server

https://excalidraw.com/#json=N0PrCUij21xc2-Zwl1phZ,VYiuI0A2Fzw8G7y5yrPY8Q

![wakuwork_counter](https://user-images.githubusercontent.com/490574/226148795-de405044-fb66-440b-9a9d-d8ad5854c7fa.png)

### Wakuwork's minimal spec for React Server Components

https://excalidraw.com/#json=VjIjQePYqfBCdnn1kiy92,75ozbvJOqCq4f8KWhYEyLQ

![wakuwork-spec](https://user-images.githubusercontent.com/490574/226770699-7390e1be-f3c1-4c72-aa7d-42bd66848866.png)

==> wakuwork-0.9.1.tgz: package/README.md <==
# Wakuwork

Minimalistic React Framework

**Use it at your own risk.**

## How to try it

- https://codesandbox.io/p/sandbox/wakuwork-example-counter-mdc1yb

## How to start a new project

```bash
npm create wakuwork
```

```bash
yarn create wakuwork
```

```bash
pnpm create wakuwork
```

## Work in progress

- [x] `wakuwork dev` (development server)
- [x] `wakuwork build` (build for production)
- [x] `wakuwork start` (production server)
- [x] Exportable build
- [x] Static site generation
- [ ] Client rendering fallback
- [x] Opt-in router (reference implementation)
- [ ] Opt-in SSR (HTML generation & hydration)

## Tweets

<details>

- https://twitter.com/dai_shi/status/1631668890861441024
- https://twitter.com/dai_shi/status/1631989295866347520
- https://twitter.com/dai_shi/status/1632005473401716736
- https://twitter.com/dai_shi/status/1632168346354593792
- https://twitter.com/dai_shi/status/1632729614450823169
- https://twitter.com/dai_shi/status/1632749501416087552
- https://twitter.com/dai_shi/status/1633262538862530561
- https://twitter.com/dai_shi/status/1633301007391424518
- https://twitter.com/dai_shi/status/1633821215206035460
- https://twitter.com/dai_shi/status/1633824588152074240
- https://twitter.com/dai_shi/status/1633826855282434048
- https://twitter.com/dai_shi/status/1634210639831867392
- https://twitter.com/dai_shi/status/1634212827706654723
- https://twitter.com/dai_shi/status/1635142924928434177
- https://twitter.com/dai_shi/status/1635149324383559681
- https://twitter.com/dai_shi/status/1635437958185766913
- https://twitter.com/dai_shi/status/1636744180902014981
- https://twitter.com/dai_shi/status/1636745339624624132
- https://twitter.com/dai_shi/status/1636746632900534273
- https://twitter.com/dai_shi/status/1637635196458778627
- https://twitter.com/dai_shi/status/1637768216817840129
- https://twitter.com/dai_shi/status/1638910110448902145
- https://twitter.com/dai_shi/status/1639858260114300931
- https://twitter.com/dai_shi/status/1640358907540537344
- https://twitter.com/dai_shi/status/1642463300314333184

</details>

## Diagrams

### Architecture

https://excalidraw.com/#json=W1apCXy3iJ3L0rIoDxtU4,AbYkm972Fm1CbIzfV5PTIQ

![wakuwork-arch](https://user-images.githubusercontent.com/490574/224886500-20833ff1-961b-4b84-972c-6471bc732de2.png)

### How React Server Functions Work

https://excalidraw.com/#json=fMeNJovUG7PGnpvP64XVw,kjZBTeM2KPZKhWtALDOY8A

![react-server-functions](https://user-images.githubusercontent.com/490574/225330279-e10cee1e-ffb9-49d1-b47c-6c46eb7f6c3a.png)

### How Wakuwork counter example communicates with server

https://excalidraw.com/#json=N0PrCUij21xc2-Zwl1phZ,VYiuI0A2Fzw8G7y5yrPY8Q

![wakuwork_counter](https://user-images.githubusercontent.com/490574/226148795-de405044-fb66-440b-9a9d-d8ad5854c7fa.png)

### Wakuwork's minimal spec for React Server Components

https://excalidraw.com/#json=VjIjQePYqfBCdnn1kiy92,75ozbvJOqCq4f8KWhYEyLQ

![wakuwork-spec](https://user-images.githubusercontent.com/490574/226770699-7390e1be-f3c1-4c72-aa7d-42bd66848866.png)
